@@ -7,8 +7,8 @@ import matplotlib.pyplot as plt
 import matplotlib.lines as lines
 from steam_sdk.wrappers.java.SIGMA import WrapperSIGMA as ws
 from steam_sdk.plotters import PlotterSIGMA as p
-from steam_sdk.data import DataRoxieParser as pd
-from steam_sdk.data.DataModel import DataModel
+from steam_sdk.data import DataRoxieParser as dR
+from steam_sdk.data.DataModelMagnet import DataModelMagnet
 
 
 class BuilderSIGMA:
@@ -16,11 +16,11 @@ class BuilderSIGMA:
         Class to generate SIGMA models
     """
 
-    def __init__(self, input_model_data: DataModel = None, input_roxie_data: pd.APIdata = None,
+    def __init__(self, input_model_data: DataModelMagnet = None, input_roxie_data: dR.APIdata = None,
                  settings_dict: dict = None, output_path: str = None, flag_build: bool = True, verbose: bool = True):
         self.verbose: bool = verbose
-        self.model_data: DataModel = input_model_data
-        self.roxie_data: pd.APIdata = input_roxie_data
+        self.model_data: DataModelMagnet = input_model_data
+        self.roxie_data: dR.APIdata = input_roxie_data
         self.settings_dict: dict = settings_dict
         if output_path:
             self.output_path: str = output_path
@@ -28,14 +28,14 @@ class BuilderSIGMA:
             self.output_path = os.getcwd()
 
         if (not self.model_data or not self.roxie_data) and flag_build:
-            raise Exception('Cannot build model without providing DataModel and RoxieData')
+            raise Exception('Cannot build model without providing DataModelMagnet and RoxieData')
         elif flag_build:
             self.g = ws.GatewaySIGMA()
             self.a = ws.ArraysSIGMA
 
             self.max_r: float = 0.0
             self.conductor_name = str
-            self.cableParameters = pd.CondPar
+            self.cableParameters = {'cable': {}, 'strand': {}, 'Jc_fit': {}}  # dM.Conductor
             # self.wedge_elements =
             # self.model =
             self.coil = []
@@ -62,7 +62,7 @@ class BuilderSIGMA:
             self.build_magnet()
             self.save_model_java()
             self.save_compile_and_open_bat()
-            #self.plot_magnet()
+            self.plot_magnet()
 
     def build_magnet(self):
         self.air_ff_domain()
@@ -163,39 +163,50 @@ class BuilderSIGMA:
 
             self.elements[i] = self.a.create_element_array(self.g.gateway, tuple(arg))
 
-    def cable_domain(self):
+    def cable_domain(self, conductor: str = None):
         """
             Cable characteristics and conductor properties
         """
-        self.g.cable.setLabel(self.conductor_name)
-        self.g.cable.setwInsulNarrow(self.cableParameters.wInsulNarrow)
-        self.g.cable.setwInsulWide(self.cableParameters.wInsulWide)
-        self.g.cable.setdFilament(self.cableParameters.dFilament)
-        self.g.cable.setDstrand(self.cableParameters.dstrand)
-        self.g.cable.setFracCu(self.cableParameters.fracCu)
-        self.g.cable.setFracSc(self.cableParameters.fracSc)
-        self.g.cable.setRRR(self.cableParameters.RRR)
-        self.g.cable.setTupRRR(self.cableParameters.TupRRR)
-        self.g.cable.setTop(self.cableParameters.Top)
-        self.g.cable.setRc(self.cableParameters.Rc)
-        self.g.cable.setRa(self.cableParameters.Ra)
-        self.g.cable.setfRhoEff(self.cableParameters.fRhoEff)
-        self.g.cable.setlTp(self.cableParameters.lTp)
-        self.g.cable.setwBare(self.cableParameters.wBare)
-        self.g.cable.sethInBare(self.cableParameters.hInBare)
-        self.g.cable.sethOutBare(self.cableParameters.hOutBare)
-        self.g.cable.setNoOfStrands(self.cableParameters.noOfStrands)
-        self.g.cable.setNoOfStrandsPerLayer(self.cableParameters.noOfStrandsPerLayer)
-        self.g.cable.setNoOfLayers(self.cableParameters.noOfLayers)
-        self.g.cable.setlTpStrand(self.cableParameters.lTpStrand)
-        self.g.cable.setwCore(self.cableParameters.wCore)
-        self.g.cable.sethCore(self.cableParameters.hCore)
-        self.g.cable.setThetaTpStrand(self.cableParameters.thetaTpStrand)
-        self.g.cable.setC1(self.cableParameters.C1)
-        self.g.cable.setC2(self.cableParameters.C2)
-        self.g.cable.setFracHe(self.cableParameters.fracHe)
-        self.g.cable.setFracFillInnerVoids(self.cableParameters.fracFillInnerVoids)
-        self.g.cable.setFractFillOuterVoids(self.cableParameters.fracFillOuterVoids)
+        self.g.cable.setLabel(conductor)
+        self.g.cable.setTop(self.model_data.GeneralParameters.T_initial)
+        i = 0
+        while conductor != self.model_data.Conductors[i].name:
+            i += 1
+        for entry in self.model_data.Conductors[i]:
+            if entry[0] == 'cable' or entry[0] == 'strand' or entry[0] == 'Jc_fit':
+                for key in entry[1]:
+                    self.cableParameters[entry[0]][key[0]] = key[1] if key[1] else 0.
+
+        self.g.cable.setwInsulNarrow(self.cableParameters['cable']['th_insulation_along_height'])
+        self.g.cable.setwInsulWide(self.cableParameters['cable']['th_insulation_along_width'])
+        self.g.cable.setRc(self.cableParameters['cable']['Rc'])
+        self.g.cable.setRa(self.cableParameters['cable']['Ra'])
+        self.g.cable.setwBare(self.cableParameters['cable']['bare_cable_width'])
+        self.g.cable.sethInBare(self.cableParameters['cable']['bare_cable_height_low'])
+        self.g.cable.sethOutBare(self.cableParameters['cable']['bare_cable_height_high'])
+        self.g.cable.setNoOfStrands(self.cableParameters['cable']['n_strands'])
+        self.g.cable.setNoOfStrandsPerLayer(self.cableParameters['cable']['n_strands_per_layers'])
+        self.g.cable.setNoOfLayers(self.cableParameters['cable']['n_strand_layers'])
+        self.g.cable.setlTpStrand(self.cableParameters['cable']['strand_twist_pitch'])
+        self.g.cable.setwCore(self.cableParameters['cable']['width_core'])
+        self.g.cable.sethCore(self.cableParameters['cable']['height_core'])
+        self.g.cable.setThetaTpStrand(self.cableParameters['cable']['strand_twist_pitch_angle'])
+        self.g.cable.setFracFillInnerVoids(self.cableParameters['cable']['f_inner_voids'])
+        self.g.cable.setFractFillOuterVoids(self.cableParameters['cable']['f_outer_voids'])
+
+        self.g.cable.setdFilament(self.cableParameters['strand']['filament_diameter'])
+        self.g.cable.setDstrand(self.cableParameters['strand']['diameter'])
+        self.g.cable.setfRhoEff(self.cableParameters['strand']['f_Rho_effective'])
+        self.g.cable.setlTp(self.cableParameters['strand']['fil_twist_pitch'])
+        self.g.cable.setRRR(self.cableParameters['strand']['RRR'])
+        self.g.cable.setTupRRR(self.cableParameters['strand']['T_ref_RRR_high'])
+        self.g.cable.setFracHe(0.)
+        self.g.cable.setFracCu(self.cableParameters['strand']['Cu_noCu_in_strand'] /
+                               (1 + self.cableParameters['strand']['Cu_noCu_in_strand']))
+        self.g.cable.setFracSc(1 / (1 + self.cableParameters['strand']['Cu_noCu_in_strand']))
+        self.g.cable.setC1(self.cableParameters['Jc_fit']['C1_' + self.cableParameters['Jc_fit']['type']])
+        self.g.cable.setC2(self.cableParameters['Jc_fit']['C2_' + self.cableParameters['Jc_fit']['type']])
+
         self.g.cable.setCriticalSurfaceFit(self.g.Cable.CriticalSurfaceFitEnum.Ic_NbTi_GSI)
         self.g.cable.setInsulationMaterial(self.g.MatDatabase.MAT_KAPTON)
         self.g.cable.setMaterialInnerVoids(self.g.MatDatabase.MAT_VOID)
@@ -214,8 +225,8 @@ class BuilderSIGMA:
                 for layer_nr, layer in pole.layers.items():
                     for winding_key, winding in layer.windings.items():
                         self.conductor_name = winding.conductor_name
-                        self.cableParameters = self.roxie_data.conductor.conductor[winding.conductor_name].parameters
-                        self.cable_domain()
+                        # self.cableParameters = self.roxie_data.conductor.conductor[winding.conductor_name].parameters
+                        self.cable_domain(conductor=winding.conductor_name)
                         areas = ()
                         currents = ()
                         for block_key, block in winding.blocks.items():
@@ -418,8 +429,7 @@ class BuilderSIGMA:
             class_paths += f'-classpathadd "{file}.jar" '
 
         script_lines += [
-            f'"{self.COMSOL_compile_path}" -jdkroot "{self.java_jdk_path}" {class_paths}'
-            f'"{self.model_java_file_path}"',
+            f'"{self.COMSOL_compile_path}" -jdkroot "{self.java_jdk_path}" {class_paths}"{self.model_java_file_path}"',
             f'"{self.COMSOL_batch_path}" -inputfile "{self.model_class_file_path}" '
             f'-outputfile "{os.path.join(self.output_path, self.model_data.GeneralParameters.magnet_name)}.mph"',
             f'"{self.COMSOL_exe_path}" -open "{os.path.join(self.output_path, self.model_name)}.mph"']
@@ -431,20 +441,24 @@ class BuilderSIGMA:
 if __name__ == "__main__":
     from steam_sdk.parsers.ParserRoxie import ParserRoxie
 
-    magnet_name = 'MQY_2in1'  #'MQXF_V2'  # 'MBX'  #
+    magnet_name = 'MQY_2in1'  #'MBH_2in1'  #'MQXA'  #'MBX'  #'MQXB'   # 'MQXF_V2'  #
     current_path = Path(__file__).parent
-    path = Path.joinpath(current_path.parent.parent, 'tests', 'builders', 'model_library','magnets', magnet_name, 'input')
+    path = Path.joinpath(current_path.parent.parent, 'tests', 'builders', 'model_library',
+                         'magnets', magnet_name, 'input')
     file_model_data = Path.joinpath(path, 'modelData_' + magnet_name + '.yaml')
     if Path.exists(file_model_data):
         with open(file_model_data, "r") as stream:
             dictionary_yaml = yaml.safe_load(stream)
-            model_data = DataModel(**dictionary_yaml)
-        path_iron = Path.joinpath(path, model_data.Sources.iron_fromROXIE)
+            model_data = DataModelMagnet(**dictionary_yaml)
+        if model_data.Sources.iron_fromROXIE:
+            path_iron = Path.joinpath(path, model_data.Sources.iron_fromROXIE)
+        else:
+            path_iron = None
         path_data = Path.joinpath(path, model_data.Sources.coil_fromROXIE)
     else:
         path_iron = None
         path_data = Path.joinpath(path, f"{magnet_name}.data")
-    path_cadata = Path.joinpath(path.parent, 'roxie.cadata')
+    path_cadata = Path.joinpath(path.parent.parent, 'roxie.cadata')
 
     roxie_parser = ParserRoxie()
     roxie_data = roxie_parser.getData(dir_data=path_data, dir_cadata=path_cadata, dir_iron=path_iron)
